#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 torrent
version:              10000.1.3
visibility:           public
id:                   torrent-10000.1.3-9uEsc0loavU5K4W2u4n7Qy
key:                  torrent-10000.1.3-9uEsc0loavU5K4W2u4n7Qy
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  2f14045abed3ee1c5febf74eb70b201e
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/torrent-10000.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-torrent
hs-libraries:         HStorrent-10000.1.3-9uEsc0loavU5K4W2u4n7Qy
depends:
    base-4.18.2.1 bencode-0.6.1.1-2iwrhpOOBi0L3UOxnodWAu binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.300.1
    syb-0.7.3-45RHZbqQsU9HukQlnlXSjw

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

